var group___b_s_p_scene_manager =
[
    [ "Ogre::BspIntersectionSceneQuery", "class_ogre_1_1_bsp_intersection_scene_query.html", [
      [ "BspIntersectionSceneQuery", "class_ogre_1_1_bsp_intersection_scene_query.html#a41f6ea17202f479bff9081bfbd69b758", null ],
      [ "execute", "class_ogre_1_1_bsp_intersection_scene_query.html#a3dbf1d10649286de4ead6b136d4f3eaa", null ],
      [ "setWorldFragmentType", "class_ogre_1_1_bsp_intersection_scene_query.html#a1f739991d9f5c0fe7d59ac431708f318", null ],
      [ "getWorldFragmentType", "class_ogre_1_1_bsp_intersection_scene_query.html#a4f51de3690a1a8ff23a6a45b2c35861c", null ],
      [ "getSupportedWorldFragmentTypes", "class_ogre_1_1_bsp_intersection_scene_query.html#aae0ab3526e9bfbf9ec85f5b6a4d99228", null ]
    ] ],
    [ "Ogre::BspLevel", "class_ogre_1_1_bsp_level.html", [
      [ "BspLevel", "class_ogre_1_1_bsp_level.html#a058020fea4785609e67b628c479e35e2", null ],
      [ "~BspLevel", "class_ogre_1_1_bsp_level.html#a5acae4086f9ac47234172d1d328b186d", null ],
      [ "isLeafVisible", "class_ogre_1_1_bsp_level.html#a0a39be276b7610046058c1e7bc90d435", null ],
      [ "getRootNode", "class_ogre_1_1_bsp_level.html#aa2fb6e7deb0c149335680b2f5d27c500", null ],
      [ "findLeaf", "class_ogre_1_1_bsp_level.html#a5cb90a141a2e97c9d287c686d36dc08a", null ],
      [ "_notifyObjectMoved", "class_ogre_1_1_bsp_level.html#ae44b5dbe3ecd07bdfd7632c1d94e5611", null ],
      [ "_notifyObjectDetached", "class_ogre_1_1_bsp_level.html#abb6bb7d410caaa37c5a9b573009232fd", null ],
      [ "getLeafStart", "class_ogre_1_1_bsp_level.html#a2fdb7708f9eab0a4406aebab77451a6a", null ],
      [ "getNumLeaves", "class_ogre_1_1_bsp_level.html#a0078f789dc5c7dfa8e909bfb5b7aa683", null ],
      [ "calculateLoadingStages", "class_ogre_1_1_bsp_level.html#a9efb7f6b93f6fcc3e3583deab5a8d1a3", null ],
      [ "calculateLoadingStages", "class_ogre_1_1_bsp_level.html#a5a35308e7576982c9960367008ee361c", null ],
      [ "load", "class_ogre_1_1_bsp_level.html#ae2326a88f279db69da5ed6c29ff8dc4b", null ],
      [ "isSkyEnabled", "class_ogre_1_1_bsp_level.html#a2262404327d01504ac157b1de7fc9c3f", null ],
      [ "getSkyMaterialName", "class_ogre_1_1_bsp_level.html#a089acbec439a13c5e3a43007040e4fde", null ],
      [ "getSkyCurvature", "class_ogre_1_1_bsp_level.html#ae9cfd5baeef2a4f1977086a1c55e3a81", null ],
      [ "getRenderOperation", "class_ogre_1_1_bsp_level.html#a44d8df426ac5ba7c704851a67e23ddd3", null ],
      [ "getWorldTransforms", "class_ogre_1_1_bsp_level.html#adb593bd086c06d636d91aa31ba51f9f2", null ],
      [ "getSquaredViewDepth", "class_ogre_1_1_bsp_level.html#ad7b7c35fe843bb3608d86a45773930e1", null ],
      [ "getLights", "class_ogre_1_1_bsp_level.html#ac1f813c46f1b8d1cf9e65960f848da10", null ],
      [ "getMaterial", "class_ogre_1_1_bsp_level.html#a102468f7968aa187a2612b4504b896e4", null ],
      [ "BspSceneManager", "class_ogre_1_1_bsp_level.html#a76934cdb132579a189b802280a1b140e", null ]
    ] ],
    [ "Ogre::BspNode", "class_ogre_1_1_bsp_node.html", [
      [ "Brush", "struct_ogre_1_1_bsp_node_1_1_brush.html", [
        [ "planes", "struct_ogre_1_1_bsp_node_1_1_brush.html#a62726d014908dee79b47d4048184afaa", null ],
        [ "fragment", "struct_ogre_1_1_bsp_node_1_1_brush.html#a1e6740b48713e3cc1fc3bdb62b9a6e64", null ]
      ] ],
      [ "IntersectingObjectSet", "class_ogre_1_1_bsp_node.html#acc9262dbc255f7b9d00ed61a30166a36", null ],
      [ "NodeBrushList", "class_ogre_1_1_bsp_node.html#a9057cc500de27abe8f6494f8dd369aac", null ],
      [ "BspNode", "class_ogre_1_1_bsp_node.html#a39b74504f7252462d27f69bbeef5dc99", null ],
      [ "BspNode", "class_ogre_1_1_bsp_node.html#a10395588ed29a1d34e3b028643dd2d77", null ],
      [ "~BspNode", "class_ogre_1_1_bsp_node.html#a74871a4318ee6f0bfdf068a988bc2496", null ],
      [ "isLeaf", "class_ogre_1_1_bsp_node.html#aaeb2ac6a36ce7bbfb351f272ff724cf8", null ],
      [ "getFront", "class_ogre_1_1_bsp_node.html#aa01bca36fdbc364f4c4ae34c588925e0", null ],
      [ "getBack", "class_ogre_1_1_bsp_node.html#a14b622c678f0ec0dfc46cca86170f88c", null ],
      [ "getSide", "class_ogre_1_1_bsp_node.html#ae4dd978cc8a7a6bcd35921d9ee37c5c7", null ],
      [ "getNextNode", "class_ogre_1_1_bsp_node.html#a9c207bdda7b0f90f29025cb6eaaf0900", null ],
      [ "getSplitPlane", "class_ogre_1_1_bsp_node.html#a77af6c00095862be4b2933674598f219", null ],
      [ "getBoundingBox", "class_ogre_1_1_bsp_node.html#aadd6ad74595abac5718fcbf6e71faad3", null ],
      [ "getNumFaceGroups", "class_ogre_1_1_bsp_node.html#aaf0f3cd4f006d876302502182569ecee", null ],
      [ "getFaceGroupStart", "class_ogre_1_1_bsp_node.html#aec9a1bc496cd833f81869079741a122b", null ],
      [ "isLeafVisible", "class_ogre_1_1_bsp_node.html#a89db45619ae315c31cd3880aad56b94c", null ],
      [ "_addMovable", "class_ogre_1_1_bsp_node.html#ac5702538be4c791af37cd73d2aa353a5", null ],
      [ "_removeMovable", "class_ogre_1_1_bsp_node.html#aa10efd90b923c891eba69bad3b06d450", null ],
      [ "getDistance", "class_ogre_1_1_bsp_node.html#adb496664856e47c5ac433dce45ec83f8", null ],
      [ "getSolidBrushes", "class_ogre_1_1_bsp_node.html#a13eb9a6c5873789d18d9dbd6aec7102b", null ],
      [ "getObjects", "class_ogre_1_1_bsp_node.html#ab7f7a40319b9eb66ceee592e9227624e", null ],
      [ "BspLevel", "class_ogre_1_1_bsp_node.html#a8c663a45872e4b89850c3ba482beaef5", null ],
      [ "operator<<", "class_ogre_1_1_bsp_node.html#aeba6c3273ed4fdf07c3aea84c2df87ab", null ]
    ] ],
    [ "Ogre::BspRaySceneQuery", "class_ogre_1_1_bsp_ray_scene_query.html", [
      [ "BspRaySceneQuery", "class_ogre_1_1_bsp_ray_scene_query.html#ae28099aef7f983a042efde7e298295b9", null ],
      [ "~BspRaySceneQuery", "class_ogre_1_1_bsp_ray_scene_query.html#af688336da3971472963b32e52b17d251", null ],
      [ "setWorldFragmentType", "class_ogre_1_1_bsp_ray_scene_query.html#ae7d9dcfa961dcaf756c5ac2b278413eb", null ],
      [ "getWorldFragmentType", "class_ogre_1_1_bsp_ray_scene_query.html#a0b402c03852f58373e2f8224242e1f4d", null ],
      [ "getSupportedWorldFragmentTypes", "class_ogre_1_1_bsp_ray_scene_query.html#a5887059ed82ee59e0e5f0ae149b244d8", null ],
      [ "execute", "class_ogre_1_1_bsp_ray_scene_query.html#a0a7e638608a44ba0b50998b84029d324", null ]
    ] ],
    [ "Ogre::BspSceneManager", "class_ogre_1_1_bsp_scene_manager.html", [
      [ "BspSceneManager", "class_ogre_1_1_bsp_scene_manager.html#ab3e178ca87404a0687e2523e756ff5fd", null ],
      [ "~BspSceneManager", "class_ogre_1_1_bsp_scene_manager.html#aa872f5ea2bedbeb7dd9cf1b25a110c35", null ],
      [ "getTypeName", "class_ogre_1_1_bsp_scene_manager.html#aefb30f708df66332b50fa83d241b2305", null ],
      [ "setWorldGeometry", "class_ogre_1_1_bsp_scene_manager.html#a14115743f2fd57a125e6e7fa485e622d", null ],
      [ "estimateWorldGeometry", "class_ogre_1_1_bsp_scene_manager.html#ac2269aefac9958545213fa85a1183408", null ],
      [ "setWorldGeometry", "class_ogre_1_1_bsp_scene_manager.html#aa5ac0d95321d764e70c0fb18e55a4915", null ],
      [ "estimateWorldGeometry", "class_ogre_1_1_bsp_scene_manager.html#a6efcddf31f81825c0092d0a60babda3b", null ],
      [ "showNodeBoxes", "class_ogre_1_1_bsp_scene_manager.html#a0f8a152457053472843eebfb6ec1bc0f", null ],
      [ "getSuggestedViewpoint", "class_ogre_1_1_bsp_scene_manager.html#a12204c33556c1f3c22c5652b6aaafa1b", null ],
      [ "getLevel", "class_ogre_1_1_bsp_scene_manager.html#a201d0b4ed0ec67b8480092dee0a5184a", null ],
      [ "setLevel", "class_ogre_1_1_bsp_scene_manager.html#a344a49c8ef3b09b290b2e14c2bfa500d", null ],
      [ "_findVisibleObjects", "class_ogre_1_1_bsp_scene_manager.html#a046c5bdaddb4c0595b6c79b10037f9e4", null ],
      [ "createSceneNodeImpl", "class_ogre_1_1_bsp_scene_manager.html#add4847839039e485bee409f229b48b40", null ],
      [ "createSceneNodeImpl", "class_ogre_1_1_bsp_scene_manager.html#a7d2c528a848b18c5c5296905737ee36c", null ],
      [ "_notifyObjectMoved", "class_ogre_1_1_bsp_scene_manager.html#af55b958c50f23943eca3132c8f154147", null ],
      [ "_notifyObjectDetached", "class_ogre_1_1_bsp_scene_manager.html#a884ea1e2f8b90a149f03de7b822c2385", null ],
      [ "createRayQuery", "class_ogre_1_1_bsp_scene_manager.html#a00bede8ae97fbfd56ae9a173aabb70e3", null ],
      [ "createIntersectionQuery", "class_ogre_1_1_bsp_scene_manager.html#a99ebf10a5f443434fae8b3208f92d088", null ]
    ] ],
    [ "Ogre::BspSceneManagerFactory", "class_ogre_1_1_bsp_scene_manager_factory.html", [
      [ "createInstance", "class_ogre_1_1_bsp_scene_manager_factory.html#a8d4635a141f5fb4a17ae0232d952f125", null ],
      [ "getTypeName", "class_ogre_1_1_bsp_scene_manager_factory.html#a89483d387ff238f181ebb69e2c5b6e67", null ],
      [ "FACTORY_TYPE_NAME", "class_ogre_1_1_bsp_scene_manager_factory.html#a00c4e589af4d4dabea98be3556c71382", null ]
    ] ],
    [ "Ogre::BspSceneNode", "class_ogre_1_1_bsp_scene_node.html", [
      [ "BspSceneNode", "class_ogre_1_1_bsp_scene_node.html#a3c9fc7c13d2a9a92130e1b595f74fe8d", null ],
      [ "BspSceneNode", "class_ogre_1_1_bsp_scene_node.html#a387df029179fce1955902d2b6cd3ae8b", null ],
      [ "_update", "class_ogre_1_1_bsp_scene_node.html#a645083e5abba280774870d26518e48ba", null ],
      [ "detachObject", "class_ogre_1_1_bsp_scene_node.html#ae01f2cdeee4fce08c95f2485fb3c5856", null ],
      [ "detachObject", "class_ogre_1_1_bsp_scene_node.html#a7925beb519b3f99fd01ed813250ce95b", null ],
      [ "detachAllObjects", "class_ogre_1_1_bsp_scene_node.html#a5aaba5c4f0ca1c0d896d9b9a753d78b1", null ]
    ] ],
    [ "Ogre::Quake3Level", "class_ogre_1_1_quake3_level.html", [
      [ "Quake3Level", "class_ogre_1_1_quake3_level.html#a34f3c49164fba86c97db55479f98204b", null ],
      [ "loadHeaderFromStream", "class_ogre_1_1_quake3_level.html#a9dcdd39024abfbf98cef0b56f664dd10", null ],
      [ "loadFromStream", "class_ogre_1_1_quake3_level.html#afd8f2933a530eed1d5078c48f931175a", null ],
      [ "extractLightmaps", "class_ogre_1_1_quake3_level.html#a5dbee61389617b58e249a2fae8ddd2b5", null ],
      [ "initialise", "class_ogre_1_1_quake3_level.html#a8e0bbc2508ca43150dabb2d297368d94", null ],
      [ "initialiseCounts", "class_ogre_1_1_quake3_level.html#a627b23228490f9c10f330364bcdb4dae", null ],
      [ "initialisePointers", "class_ogre_1_1_quake3_level.html#af980b63b8a960930082fe58321218499", null ],
      [ "getLump", "class_ogre_1_1_quake3_level.html#a2e9c6aca2404f5dde85f83eccdd622c9", null ],
      [ "getLumpSize", "class_ogre_1_1_quake3_level.html#a65a7fab400575fcf6f654cbb6cc0f87d", null ],
      [ "dumpContents", "class_ogre_1_1_quake3_level.html#a6f6a8604a0f80c4db59d8c630a69910a", null ],
      [ "mChunk", "class_ogre_1_1_quake3_level.html#ac5b187531ca3ea3f8ed6c05e36c536b9", null ],
      [ "mHeader", "class_ogre_1_1_quake3_level.html#a40578ec27f37435745b345ea975ef85d", null ],
      [ "mLumpStart", "class_ogre_1_1_quake3_level.html#ad62b759955f9a526a10b1c39d237c84f", null ],
      [ "mElements", "class_ogre_1_1_quake3_level.html#a2acfd1b5ad4a076b080f6992dc9c2f9d", null ],
      [ "mNumElements", "class_ogre_1_1_quake3_level.html#ab4bc1871ee8df18efeea396702759d69", null ],
      [ "mEntities", "class_ogre_1_1_quake3_level.html#ae6fce6b8862c5fc35ee94d3fb21f3e57", null ],
      [ "mNumEntities", "class_ogre_1_1_quake3_level.html#a815a5461cb601dd34c2763be92ff8e63", null ],
      [ "mModels", "class_ogre_1_1_quake3_level.html#a76ef64eadd5efca15be9c437242bbb2a", null ],
      [ "mNumModels", "class_ogre_1_1_quake3_level.html#a6a759263794d11dbe6ed691cb9eb4822", null ],
      [ "mNodes", "class_ogre_1_1_quake3_level.html#a75a2be9a57305260131a322e388f6662", null ],
      [ "mNumNodes", "class_ogre_1_1_quake3_level.html#ad7bd4deb8c5a2fef5a3995d1f7b44a92", null ],
      [ "mLeaves", "class_ogre_1_1_quake3_level.html#a78223ef26d9805187716150d3b6095e2", null ],
      [ "mNumLeaves", "class_ogre_1_1_quake3_level.html#a7113d1bfb7498aa8830bd658b3c50820", null ],
      [ "mLeafFaces", "class_ogre_1_1_quake3_level.html#a64d071ad3a22b0d28cdb88d0c161a116", null ],
      [ "mNumLeafFaces", "class_ogre_1_1_quake3_level.html#a0dabe8022c92c8474c8bb09eb0731ad2", null ],
      [ "mPlanes", "class_ogre_1_1_quake3_level.html#a803cec1cc897f9f77dffc179907c3271", null ],
      [ "mNumPlanes", "class_ogre_1_1_quake3_level.html#aa70946a097c4c1ca30d4e4b703001e06", null ],
      [ "mFaces", "class_ogre_1_1_quake3_level.html#a578fc34a9e93d0486962f70ee5d6744f", null ],
      [ "mNumFaces", "class_ogre_1_1_quake3_level.html#a8e8d59282d68f7fddf3da740a7b16026", null ],
      [ "mVertices", "class_ogre_1_1_quake3_level.html#ae9f125b3933bdc658300b6f9cd84dd47", null ],
      [ "mNumVertices", "class_ogre_1_1_quake3_level.html#afe2fa0b137dc9563030b6279440059a7", null ],
      [ "mShaders", "class_ogre_1_1_quake3_level.html#a17f39ebd42aa55a73805b21b2a71436e", null ],
      [ "mNumShaders", "class_ogre_1_1_quake3_level.html#aba7de8486837255aa713299c72109893", null ],
      [ "mLightmaps", "class_ogre_1_1_quake3_level.html#acbc07544fa5c7deb7c9e0be8b339603e", null ],
      [ "mNumLightmaps", "class_ogre_1_1_quake3_level.html#abf79e30236f7a13ad480e03090e8b53f", null ],
      [ "mVis", "class_ogre_1_1_quake3_level.html#a058deee088e022627e5544116f9c92b0", null ],
      [ "mBrushes", "class_ogre_1_1_quake3_level.html#a7553ee95b6dd1d91519891bb8492a7cd", null ],
      [ "mNumBrushes", "class_ogre_1_1_quake3_level.html#a792418f15d8b55468f8fca1d951de834", null ],
      [ "mBrushSides", "class_ogre_1_1_quake3_level.html#a14b772c2df273e7657ae96bc2f422671", null ],
      [ "mNumBrushSides", "class_ogre_1_1_quake3_level.html#aa5461890bdcf1b9c0f9bd92e9d451298", null ],
      [ "mLeafBrushes", "class_ogre_1_1_quake3_level.html#a3b1152a46a229ef9c4ed095869ac189d", null ],
      [ "mNumLeafBrushes", "class_ogre_1_1_quake3_level.html#a46d8cb998181b7176028ec1390e4a646", null ]
    ] ],
    [ "Ogre::Quake3Shader", "class_ogre_1_1_quake3_shader.html", [
      [ "Pass", "struct_ogre_1_1_quake3_shader_1_1_pass.html", [
        [ "flags", "struct_ogre_1_1_quake3_shader_1_1_pass.html#a1555134dcc9e0223d19f3f65de587946", null ],
        [ "textureName", "struct_ogre_1_1_quake3_shader_1_1_pass.html#a199809151a74b6f2c3f86528759771d9", null ],
        [ "texGen", "struct_ogre_1_1_quake3_shader_1_1_pass.html#ab3b79da1e3631379d38cff0ef86c5490", null ],
        [ "blend", "struct_ogre_1_1_quake3_shader_1_1_pass.html#a21148dd1df7ac8f45dbee7e8a6451e34", null ],
        [ "blendSrc", "struct_ogre_1_1_quake3_shader_1_1_pass.html#a37338ae45cc02d33b37d31ff0f34ec3f", null ],
        [ "blendDest", "struct_ogre_1_1_quake3_shader_1_1_pass.html#af122f09765cb6682a94753debb48b9a5", null ],
        [ "customBlend", "struct_ogre_1_1_quake3_shader_1_1_pass.html#a55827b0c1a7e1790dbcb4381fad31b8b", null ],
        [ "depthFunc", "struct_ogre_1_1_quake3_shader_1_1_pass.html#a0730bb8e78945c7feae9359addc7ad5f", null ],
        [ "addressMode", "struct_ogre_1_1_quake3_shader_1_1_pass.html#af6af982b347496ff44dca5e0d85e1e6f", null ],
        [ "rgbGenFunc", "struct_ogre_1_1_quake3_shader_1_1_pass.html#adaef3dd8492ec22558457c6d9de57f07", null ],
        [ "rgbGenWave", "struct_ogre_1_1_quake3_shader_1_1_pass.html#a44c9b326ef66d4b0ea22c1b75a893bc3", null ],
        [ "rgbGenParams", "struct_ogre_1_1_quake3_shader_1_1_pass.html#ad7deedc4f2ad7ebf34ee611258a9a99f", null ],
        [ "tcModScale", "struct_ogre_1_1_quake3_shader_1_1_pass.html#a37ced2ef5b0662c4f499472eda940fe1", null ],
        [ "tcModRotate", "struct_ogre_1_1_quake3_shader_1_1_pass.html#a0c4523d558327ebc0648d5ab2f3c0ae1", null ],
        [ "tcModScroll", "struct_ogre_1_1_quake3_shader_1_1_pass.html#a2060494d1c823b201d035ba5b3ecf198", null ],
        [ "tcModTransform", "struct_ogre_1_1_quake3_shader_1_1_pass.html#afc83d576f34f26377e7e6f004a1f1aaf", null ],
        [ "tcModTurbOn", "struct_ogre_1_1_quake3_shader_1_1_pass.html#a910836986895508d0f645ed99550a691", null ],
        [ "tcModTurb", "struct_ogre_1_1_quake3_shader_1_1_pass.html#a24c80944317dc7c498f3bd7e23178a81", null ],
        [ "tcModStretchWave", "struct_ogre_1_1_quake3_shader_1_1_pass.html#a2b742b8bf61699f1e4d1ffa7ab2596f1", null ],
        [ "tcModStretchParams", "struct_ogre_1_1_quake3_shader_1_1_pass.html#aaa52ccc20e4134795b521932fd11407a", null ],
        [ "alphaFunc", "struct_ogre_1_1_quake3_shader_1_1_pass.html#a629322a4337eeaab55daa95971526d15", null ],
        [ "alphaVal", "struct_ogre_1_1_quake3_shader_1_1_pass.html#a66c7735d35b474b4bedbf1f994a13f07", null ],
        [ "animFps", "struct_ogre_1_1_quake3_shader_1_1_pass.html#aae6bb5f6978acbf0705e42bccec0fcf2", null ],
        [ "animNumFrames", "struct_ogre_1_1_quake3_shader_1_1_pass.html#addc13b69cc91bcd4ae2369ccc9395b80", null ],
        [ "frames", "struct_ogre_1_1_quake3_shader_1_1_pass.html#ab9dad7d52b2eefbf3258fd63d67e9d34", null ]
      ] ],
      [ "PassList", "class_ogre_1_1_quake3_shader.html#aba12a46a11f6e8b0b19f1498a400a6be", null ],
      [ "Quake3Shader", "class_ogre_1_1_quake3_shader.html#ac0b6f67499f46ba23725a05a0e60d17d", null ],
      [ "~Quake3Shader", "class_ogre_1_1_quake3_shader.html#a3efafbb73d988f264688b9717f27ce88", null ],
      [ "createAsMaterial", "class_ogre_1_1_quake3_shader.html#a4f1c3ec931337a69a7edcb2fa62cb0ee", null ],
      [ "flags", "class_ogre_1_1_quake3_shader.html#a998c167411f07d9ee3e7f95cc5c1554a", null ],
      [ "numPasses", "class_ogre_1_1_quake3_shader.html#a48f817b66499c02d8d4f47ae8198066e", null ],
      [ "pass", "class_ogre_1_1_quake3_shader.html#aeca19371ba22a7d01df9eaeab3ed9d66", null ],
      [ "farbox", "class_ogre_1_1_quake3_shader.html#a2f7423114a04b0658cdd7054cb3e74b1", null ],
      [ "farboxName", "class_ogre_1_1_quake3_shader.html#a6f3023f6aa4b588ff439f71f3f4f7963", null ],
      [ "skyDome", "class_ogre_1_1_quake3_shader.html#a74e4651c3b9dec1d99c402ad756d0595", null ],
      [ "cloudHeight", "class_ogre_1_1_quake3_shader.html#a9af19367349f5a64cbd834b3088ce770", null ],
      [ "deformFunc", "class_ogre_1_1_quake3_shader.html#a8cbcb41829eb6122ed616d9cff4979fb", null ],
      [ "deformParams", "class_ogre_1_1_quake3_shader.html#a79044175c8a5a07064385a9b274e2106", null ],
      [ "cullMode", "class_ogre_1_1_quake3_shader.html#a3a28219c238c5963fefda9e2c78a91bd", null ],
      [ "fog", "class_ogre_1_1_quake3_shader.html#a850367a4b81bc8cca5038a933e7a1bec", null ],
      [ "fogColour", "class_ogre_1_1_quake3_shader.html#acf534e3515696efa77c494c5cdc81037", null ],
      [ "fogDistance", "class_ogre_1_1_quake3_shader.html#a93981881b949bba28d70cbdc5b4aec23", null ]
    ] ],
    [ "Ogre::Quake3ShaderManager", "class_ogre_1_1_quake3_shader_manager.html", [
      [ "Quake3ShaderManager", "class_ogre_1_1_quake3_shader_manager.html#af2d238e94a372c870e1348ce91f9ad10", null ],
      [ "~Quake3ShaderManager", "class_ogre_1_1_quake3_shader_manager.html#ad533bdc0349934d72a80416f61320332", null ],
      [ "getScriptPatterns", "class_ogre_1_1_quake3_shader_manager.html#a079c9d93c0b5f4076758763fb87b440b", null ],
      [ "parseScript", "class_ogre_1_1_quake3_shader_manager.html#a33721e998819c9298a3f0fa4d708a4ff", null ],
      [ "getLoadingOrder", "class_ogre_1_1_quake3_shader_manager.html#abb09d9ae90d45513cc4a08352f91d332", null ],
      [ "create", "class_ogre_1_1_quake3_shader_manager.html#aab8a07097e52cde7f056ed62bd2fa4c3", null ],
      [ "clear", "class_ogre_1_1_quake3_shader_manager.html#aa9db24c7fdb71cc3ffc9b4fbf7272e39", null ],
      [ "getByName", "class_ogre_1_1_quake3_shader_manager.html#ae1fabdd007bb92605be703071621ce1b", null ],
      [ "getSingleton", "class_ogre_1_1_quake3_shader_manager.html#aa0bad36e8df7664db8b328482b685248", null ],
      [ "getSingletonPtr", "class_ogre_1_1_quake3_shader_manager.html#a46aa2bf27c8c4e9a1a48897caf957c62", null ]
    ] ],
    [ "Ogre::WorldFragment", "struct_ogre_1_1_world_fragment.html", [
      [ "fragmentType", "struct_ogre_1_1_world_fragment.html#a95b204d1af457cd4b264831797bb1abf", null ],
      [ "singleIntersection", "struct_ogre_1_1_world_fragment.html#a99febd2258d655b97d811d449bc39a2b", null ],
      [ "planes", "struct_ogre_1_1_world_fragment.html#aa03b744a5ed87918575241cf81ad873c", null ],
      [ "geometry", "struct_ogre_1_1_world_fragment.html#aa18b1aeb11d41f42e8ee59d5bfd47fcf", null ],
      [ "renderOp", "struct_ogre_1_1_world_fragment.html#a057992735c3d3b6642ccf76fe2768841", null ]
    ] ],
    [ "Ogre::BspLevelPtr", "group___b_s_p_scene_manager.html#ga83b646ec80fbd38a752530bc86f77971", null ],
    [ "Ogre::WorldFragmentType", "group___b_s_p_scene_manager.html#ga9d3d1b15230ef9bfab0ae4e8af2ceee7", [
      [ "Ogre::WFT_NONE", "group___b_s_p_scene_manager.html#gga9d3d1b15230ef9bfab0ae4e8af2ceee7aba2a479c0710afc0c5de7c790f78ca8d", null ],
      [ "Ogre::WFT_PLANE_BOUNDED_REGION", "group___b_s_p_scene_manager.html#gga9d3d1b15230ef9bfab0ae4e8af2ceee7a2fa4eedaa92804519c7245dcd7c1b3fd", null ],
      [ "Ogre::WFT_SINGLE_INTERSECTION", "group___b_s_p_scene_manager.html#gga9d3d1b15230ef9bfab0ae4e8af2ceee7a8de3089cc41bd7cc140633f9570c649b", null ],
      [ "Ogre::WFT_CUSTOM_GEOMETRY", "group___b_s_p_scene_manager.html#gga9d3d1b15230ef9bfab0ae4e8af2ceee7ad058d64707ba9f51443f7b2b18191c80", null ],
      [ "Ogre::WFT_RENDER_OPERATION", "group___b_s_p_scene_manager.html#gga9d3d1b15230ef9bfab0ae4e8af2ceee7a360231a6b7fc29efff7dfd727d56a867", null ]
    ] ]
];